# MTAmazon 0.1
# Amazon Associates plugin for Movable Type
#
# Copyright 2002 Kalsey Consulting Group
# http://kalsey.com/
# Using this software signifies your acceptance of the license
# file that accompanies this software.
#
# Installation and usage instructions can be found at
# http://kalsey.com/blog/2002/07/amazon_plugin.stm

use MT::Template::Context;
MT::Template::Context->add_container_tag(Amazon => sub { &Amazon; });
MT::Template::Context->add_tag(AmazonTitle => sub { &AmazonTitle; });
MT::Template::Context->add_tag(AmazonASIN => sub { &AmazonASIN; });
MT::Template::Context->add_tag(AmazonAuthor => sub { &AmazonAuthor; });
MT::Template::Context->add_tag(AmazonImage => sub { &AmazonImage; });
MT::Template::Context->add_tag(AmazonSmallImage => sub { &AmazonSmallImage; });
MT::Template::Context->add_tag(AmazonSalePrice => sub { &AmazonSalePrice; });
MT::Template::Context->add_tag(AmazonListPrice => sub { &AmazonListPrice; });
MT::Template::Context->add_tag(AmazonReleaseDate => sub { &AmazonReleaseDate; });
MT::Template::Context->add_tag(AmazonAvailability => sub { &AmazonAvailability; });
MT::Template::Context->add_tag(AmazonLink => sub { &AmazonLink; });
MT::Template::Context->add_tag(AmazonXML => sub { &AmazonXML; });

sub Amazon {
    my($ctx, $args) = @_;
    use XML::Simple;
    use LWP::UserAgent;
	my $url = "";
	defined(my $associateid = $args->{associateid})
        or return $ctx->error("You used <MTAmazon> without an associate id.");
	defined(my $method = $args->{method})
        or return $ctx->error("You used <MTAmazon> without a search method.");
	defined(my $search = $args->{search})
        or return $ctx->error("You used <MTAmazon> without a search string.");
	defined(my $line = $args->{line})
        or return $ctx->error("You used <MTAmazon> without a product line.");
    my $lastn = $args->{lastn} ? $args->{lastn} : 15;
    return ''
        if $lastn == 0;
    $search =~ s/\s+/\+/g;
    $url = "http://rcm.amazon.com/e/cm?t=$associateid" .
        ($method eq 'browse' ? 
        "&l=bn1&browse=$search" :
        "&l=st1&search=$search") .
        "&mode=$line&p=102&o=1&f=xml";
	my $ua = new LWP::UserAgent;
	$ua->agent('MTAmazon');
	my $http_request = new HTTP::Request('GET', $url);
	my $http_response = $ua->request($http_request);
	my $content = $http_response->{'_content'};
    $ctx->stash('AmazonXML', $content);
	my $content_tree;
	eval { $content_tree = XMLin($content) };
	return '' unless (!$@ and ref $content_tree and $content_tree->{product});
	my $tokens = $ctx->stash('tokens');
    my $builder = $ctx->stash('builder');
    my $prod = '';
    my $count = 1;
    for my $i (@{$content_tree->{'product'}}) {
        last if $count > $lastn;
        $count++;
        $ctx->stash('AmazonTitle', $i->{title});
        $ctx->stash('AmazonASIN', $i->{asin});
        $ctx->stash('AmazonAuthor', $i->{author});
        $ctx->stash('AmazonImage', $i->{image});
        $ctx->stash('AmazonSmallImage', $i->{small_image});
        $ctx->stash('AmazonSalePrice', $i->{our_price});
        $ctx->stash('AmazonListPrice', $i->{list_price});
        $ctx->stash('AmazonReleaseDate', $i->{release_date});
        $ctx->stash('AmazonAvailability', $i->{availability});
        $ctx->stash('AmazonLink', $i->{tagged_url});
        my $out = $builder->build($ctx, $tokens);
        return $ctx->error( $builder->errstr ) unless defined $out;
        $prod .= $out;
    }
    $prod;
}

sub AmazonTitle {
	my $ctx = shift;
    $ctx->stash('AmazonTitle');
}

sub AmazonASIN {
	my $ctx = shift;
    $ctx->stash('AmazonASIN')||'';
}

sub AmazonAuthor {
	my $ctx = shift;
    $ctx->stash('AmazonAuthor')||'';
}

sub AmazonImage {
	my $ctx = shift;
    $ctx->stash('AmazonImage')||'';
}

sub AmazonSmallImage {
	my $ctx = shift;
    $ctx->stash('AmazonSmallImage')||'';
}

sub AmazonSalePrice {
	my $ctx = shift;
    $ctx->stash('AmazonSalePrice')||'';
}

sub AmazonListPrice {
	my $ctx = shift;
    $ctx->stash('AmazonListPrice')||$ctx->stash('AmazonSalePrice');
}

sub AmazonReleaseDate {
	my($ctx, $args) = @_;
    use MT::Util qw( format_ts );
    return '' 
        unless $ctx->stash('AmazonReleaseDate');
    my $out = $args->{'format'} ? 
        format_ts($args->{'format'}, $ctx->stash('AmazonReleaseDate') . "000000", $ctx->stash('blog')) : 
        $ctx->stash('AmazonReleaseDate');
    $out =~ s/\b0{1,2}[,\b]+//g;
    $out;
}

sub AmazonAvailability {
	my $ctx = shift;
    $ctx->stash('AmazonAvailability');
}

sub AmazonLink {
	my $ctx = shift;
    $ctx->stash('AmazonLink');
}

sub AmazonXML {
    my $ctx = shift;
    $ctx->stash('AmazonXML');
}
